@@ -8,8 +8,13 @@ NULL
 #' Temporarily change graphics parameters.
 #'
 #' @template with
-#' @param new \code{[named list]}\cr New graphics parameters and their values
-#' @param no.readonly \code{[logical(1)]}\cr see \code{\link{par}} documentation.
-#' @seealso \code{\link{par}}
+#' @param new `[named list]`\cr New graphics parameters and their values
+#' @param no.readonly `[logical(1)]`\cr see [par()] documentation.
+#' @inheritParams with_collate
+#' @seealso [par()]
 #' @export
 with_par <- with_(graphics::par)
+
+#' @rdname with_par
+#' @export
+local_par <- local_(graphics::par)
