@@ -20,9 +20,14 @@ set_path <- function(path, action = "prefix") {
 #' Temporarily change the system search path.
 #'
 #' @template with
-#' @param new \code{[character]}\cr New \code{PATH} entries
-#' @param action \code{[character(1)]}\cr Should new values \code{"replace"}, \code{"prefix"} or
-#'   \code{"suffix"} existing paths
-#' @seealso \code{\link{Sys.setenv}}
+#' @param new `[character]`\cr New `PATH` entries
+#' @param action `[character(1)]`\cr Should new values `"replace"`, `"prefix"` or
+#'   `"suffix"` existing paths
+#' @inheritParams with_collate
+#' @seealso [Sys.setenv()]
 #' @export
 with_path <- with_(set_path, function(old) set_path(old, "replace"))
+
+#' @rdname with_path
+#' @export
+local_path <- local_(set_path, function(old) set_path(old, "replace"))
